==> django-dash-0.1.4.tar.gz: django-dash-0.1.4/src/dash/contrib/plugins/url/dash_plugins.py <==
__all__ = ('URLPlugin',)

from django.utils.translation import ugettext_lazy as _

from dash.base import BaseDashboardPlugin, plugin_registry, plugin_widget_registry
from dash.contrib.plugins.url.forms import URLForm
from dash.contrib.plugins.url.dash_widgets import URLAndroidMainWidget, URLAndroidShortcutWidget
from dash.contrib.plugins.url.dash_widgets import URLWindows8MainWidget, URLWindows8SidebarWidget

# *************************************************************************
# ******************************* URL plugin ******************************
# *************************************************************************

class URLPlugin(BaseDashboardPlugin):
    """
    URL dashboard plugin.
    """
    uid = 'url'
    name = _("URL")
    group = _("URLs")
    form = URLForm

    @property
    def html_class(self):
        """
        If plugin has an image, we add a class `iconic` to it.
        """
        html_class = super(URLPlugin, self).html_class
        if self.data.image:
            html_class += ' iconic-url'
        return html_class

plugin_registry.register(URLPlugin)

# *************************************************************************
# ****************** Registering the widgets for URL plugin ***************
# *************************************************************************

# Registering the Android widgets for URL plugin.
plugin_widget_registry.register(URLAndroidMainWidget)
plugin_widget_registry.register(URLAndroidShortcutWidget)

# Registering the Windows8widgets for URL plugin.
plugin_widget_registry.register(URLWindows8MainWidget)
plugin_widget_registry.register(URLWindows8SidebarWidget)

==> django-dash-0.2.tar.gz: django-dash-0.2/src/dash/contrib/plugins/url/dash_plugins.py <==
__all__ = ('URL1x1Plugin',)

from django.utils.translation import ugettext_lazy as _

from dash.base import BaseDashboardPlugin, plugin_registry, plugin_widget_registry
from dash.contrib.plugins.url.forms import URLForm
from dash.contrib.plugins.url.dash_widgets import URL1x1AndroidMainWidget, URL1x1AndroidShortcutWidget
from dash.contrib.plugins.url.dash_widgets import URL1x1Windows8MainWidget, URL1x1Windows8SidebarWidget

# *************************************************************************
# ******************************* URL plugin ******************************
# *************************************************************************

class URL1x1Plugin(BaseDashboardPlugin):
    """
    URL dashboard plugin.
    """
    uid = 'url_1x1'
    name = _("URL")
    group = _("URLs")
    form = URLForm

    @property
    def html_class(self):
        """
        If plugin has an image, we add a class `iconic` to it.
        """
        html_class = super(URL1x1Plugin, self).html_class
        if self.data.image:
            html_class += ' iconic-url'
        return html_class

plugin_registry.register(URL1x1Plugin)

# *************************************************************************
# ****************** Registering the widgets for URL plugin ***************
# *************************************************************************

# Registering the Android widgets for URL plugin.
plugin_widget_registry.register(URL1x1AndroidMainWidget)
plugin_widget_registry.register(URL1x1AndroidShortcutWidget)

# Registering the Windows8widgets for URL plugin.
plugin_widget_registry.register(URL1x1Windows8MainWidget)
plugin_widget_registry.register(URL1x1Windows8SidebarWidget)
